# 🧾 docu-lite
### Zero-dependency HTML doc viewer for Python. 
#### Browse classes and functions with collapsible docstrings in a tidy, readable format.

This is the MVP upload. Coming soon 
  - command line arguments

Just 100 lines to make HTML for this:

![Capture](https://github.com/user-attachments/assets/c2eb5243-5666-428a-a1f7-4a09ec127285)

